==> 1.0.0.tar.gz: lib/widgets/specials/hinge.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import 'package:vector_math/vector_math_64.dart' as Math;
import 'package:flutter/widgets.dart';

import '../../utils/perspective.dart';
import '../../utils/animator.dart';

class Hinge extends StatefulWidget {
  final Widget child;
  final Duration offset;
  final Duration duration;
  final AnimationStatusListener animationStatusListener;

  Hinge({
    @required this.child,
    this.offset = Duration.zero,
    this.duration = const Duration(seconds: 1),
    this.animationStatusListener,
  }) {
    assert(child != null, 'Error: child in $this cannot be null');
    assert(offset != null, 'Error: offset in $this cannot be null');
    assert(duration != null, 'Error: duration in $this cannot be null');
  }

  @override
  _HingeState createState() => _HingeState();
}

class _HingeState extends State<Hinge> with SingleAnimatorStateMixin {
  @override
  Widget build(BuildContext context) {
    return FadeTransition(
      opacity: animation.get("opacity"),
      child: AnimatedBuilder(
        animation: animation.controller,
        child: widget.child,
        builder: (BuildContext context, Widget child) => Transform(
          transform: Perspective.matrix(4.0) *
              Matrix4.translationValues(
                  0.0, animation.get("translateY").value, 0.0) *
              Matrix4.rotationZ(animation.get("rotateZ").value),
          child: widget.child,
          alignment: Alignment.topLeft,
        ),
      ),
    );
  }

  @override
  Animator createAnimation() {
    return Animator.sync(this)
        .at(offset: widget.offset, duration: widget.duration)
        .add(
          key: "opacity",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 80, value: 1.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 0.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .add(
          key: "translateY",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 80, value: 0.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 700.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .add(
          key: "rotateZ",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 0, value: 0.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 20,
                  value: Math.radians(80.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 40,
                  value: Math.radians(60.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 60,
                  value: Math.radians(80.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 80,
                  value: Math.radians(60.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 0.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .addStatusListener(widget.animationStatusListener)
        .generate();
  }
}

==> 1.1.2.tar.gz: lib/widgets/specials/hinge.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import '../../flutter_animator.dart';
import 'package:vector_math/vector_math_64.dart' as Math;
import 'package:flutter/widgets.dart';

import '../../utils/perspective.dart';

class Hinge extends AnimatorWidget {
  Hinge({
    Key key,
    @required Widget child,
    AnimatorPreferences prefs = const AnimatorPreferences(),
  }) : super(key: key, child: child, prefs: prefs);

  @override
  HingeState createState() => HingeState();
}

class HingeState extends AnimatorWidgetState<Hinge> {
  @override
  Widget renderAnimation(BuildContext context) {
    return FadeTransition(
      opacity: animation.get("opacity"),
      child: AnimatedBuilder(
        animation: animation.controller,
        child: widget.child,
        builder: (BuildContext context, Widget child) => Transform(
          transform: Perspective.matrix(4.0) *
              Matrix4.translationValues(
                  0.0, animation.get("translateY").value, 0.0) *
              Matrix4.rotationZ(animation.get("rotateZ").value),
          child: widget.child,
          alignment: Alignment.topLeft,
        ),
      ),
    );
  }

  @override
  Animator createAnimation(Animator animation) {
    return animation
        .at(offset: widget.prefs.offset, duration: widget.prefs.duration)
        .add(
          key: "opacity",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 80, value: 1.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 0.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .add(
          key: "translateY",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 80, value: 0.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 700.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .add(
          key: "rotateZ",
          tweens: TweenList<double>(
            [
              TweenPercentage(percent: 0, value: 0.0, curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 20,
                  value: Math.radians(80.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 40,
                  value: Math.radians(60.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 60,
                  value: Math.radians(80.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 80,
                  value: Math.radians(60.0),
                  curve: Curves.easeInOut),
              TweenPercentage(
                  percent: 100, value: 0.0, curve: Curves.easeInOut),
            ],
          ),
        )
        .addStatusListener(widget.prefs.animationStatusListener);
  }
}
